@@ -1,8 +1,10 @@
 # flake8: noqa: F401
+from .exceptions import (
+    CircularReferenceError,
+    DuplicatedRegistrationError,
+    MappingError,
+)
 from .mapper import Mapper
-
-from .exceptions import DuplicatedRegistrationError, MappingError, CircularReferenceError
-
 from .mapper_initializer import create_mapper
 
 # Global mapper
