@@ -1,8 +1,7 @@
-from typing import Type, TypeVar, Iterable
+from typing import Iterable, Type, TypeVar
 
 from automapper import Mapper
 
-
 T = TypeVar("T")
 _IGNORED_FIELDS = ("return", "args", "kwargs")
 
@@ -12,7 +11,10 @@ def __init_method_classifier__(target_cls: Type[T]) -> bool:
     return (
         hasattr(target_cls, "__init__")
         and hasattr(getattr(target_cls, "__init__"), "__annotations__")
-        and isinstance(getattr(getattr(target_cls, "__init__"), "__annotations__"), dict)
+        and isinstance(
+            getattr(getattr(target_cls, "__init__"), "__annotations__"), dict
+        )
+        and getattr(getattr(target_cls, "__init__"), "__annotations__")
     )
 
 
